@@ -5,10 +5,17 @@ from django.utils.safestring import mark_safe
 from django.contrib.admin.views.main import ALL_VAR, PAGE_VAR
 from django.utils.html import escape
 try:
-    from urlparse import parse_qs
-except ImportError:
+    # Python 3.
     from urllib.parse import parse_qs
-
+except ImportError:
+    # Python 2.5+
+    from urlparse import urlparse
+    try:
+        # Python 2.6+
+        from urlparse import parse_qs
+    except ImportError:
+        # Python <=2.5
+        from cgi import parse_qs
 
 register = template.Library()
 
